==================
Arasel Python Test
==================


.. image:: https://img.shields.io/pypi/v/arasel_test.svg
        :target: https://pypi.python.org/pypi/arasel_test



Test Solution to TransfCustomer Lifetime Value for each customer in input CSV.


* Free software: MIT license
* Documentation: https://arasel-test.readthedocs.io.


Instalation
--------

```pip install arasel_test```

Usage
--------

```arasel_test --orders=/path/to/orders.csv --model=/path/to/model.dill --output=/path/to/output.csv --port=8080```


OR
--------

Clone this repository, install requirements.txt, add arasel_test directory to PYTHONPATH, and then:

```python app.py```
